@@ -29,7 +29,6 @@
 
 #include "empathy-account-settings.h"
 #include "empathy-connection-managers.h"
-#include "empathy-keyring.h"
 #include "empathy-utils.h"
 #include "empathy-idle.h"
 
@@ -44,18 +43,12 @@ enum {
   PROP_ACCOUNT = 1,
   PROP_CM_NAME,
   PROP_PROTOCOL,
+  PROP_SERVICE,
   PROP_DISPLAY_NAME,
   PROP_DISPLAY_NAME_OVERRIDDEN,
   PROP_READY
 };
 
-enum {
-  PASSWORD_RETRIEVED = 1,
-  LAST_SIGNAL
-};
-
-static gulong signals[LAST_SIGNAL] = { 0, };
-
 /* private structure */
 typedef struct _EmpathyAccountSettingsPriv EmpathyAccountSettingsPriv;
 
@@ -66,32 +59,21 @@ struct _EmpathyAccountSettingsPriv
   TpAccountManager *account_manager;
 
   TpConnectionManager *manager;
-  TpProtocol *protocol_obj;
 
   TpAccount *account;
   gchar *cm_name;
   gchar *protocol;
+  gchar *service;
   gchar *display_name;
   gchar *icon_name;
   gboolean display_name_overridden;
   gboolean ready;
 
-  gboolean supports_sasl;
-  gboolean password_changed;
-
-  gchar *password;
-  gchar *password_original;
-
-  gboolean password_retrieved;
-  gboolean password_requested;
-
-  /* Parameter name (gchar *) -> parameter value (GValue) */
   GHashTable *parameters;
   GArray *unset_parameters;
   GArray *required_params;
 
   gulong managers_ready_id;
-  gboolean preparing_protocol;
 
   GSimpleAsyncResult *apply_result;
 };
@@ -143,6 +125,9 @@ empathy_account_settings_set_property (GObject *object,
       case PROP_PROTOCOL:
         priv->protocol = g_value_dup_string (value);
         break;
+      case PROP_SERVICE:
+        priv->service = g_value_dup_string (value);
+        break;
       case PROP_DISPLAY_NAME:
         priv->display_name = g_value_dup_string (value);
         break;
@@ -175,6 +160,9 @@ empathy_account_settings_get_property (GObject *object,
       case PROP_PROTOCOL:
         g_value_set_string (value, priv->protocol);
         break;
+      case PROP_SERVICE:
+        g_value_set_string (value, priv->service);
+        break;
       case PROP_DISPLAY_NAME:
         g_value_set_string (value, priv->display_name);
         break;
@@ -200,11 +188,14 @@ empathy_account_settings_constructed (GObject *object)
     {
       g_free (priv->cm_name);
       g_free (priv->protocol);
+      g_free (priv->service);
 
       priv->cm_name =
         g_strdup (tp_account_get_connection_manager (priv->account));
       priv->protocol =
         g_strdup (tp_account_get_protocol (priv->account));
+      priv->service =
+        g_strdup (tp_account_get_service (priv->account));
       priv->icon_name = g_strdup
         (tp_account_get_icon_name (priv->account));
     }
@@ -219,17 +210,8 @@ empathy_account_settings_constructed (GObject *object)
 
   if (!priv->ready)
     {
-      GQuark features[] = {
-          TP_ACCOUNT_FEATURE_CORE,
-          TP_ACCOUNT_FEATURE_STORAGE,
-          0 };
-
-      if (priv->account != NULL)
-        {
-          tp_proxy_prepare_async (priv->account, features,
-              empathy_account_settings_account_ready_cb, self);
-        }
-
+      tp_account_prepare_async (priv->account, NULL,
+          empathy_account_settings_account_ready_cb, self);
       tp_g_signal_connect_object (priv->managers, "notify::ready",
         G_CALLBACK (empathy_account_settings_managers_ready_cb), object, 0);
     }
@@ -277,6 +259,13 @@ empathy_account_settings_class_init (
       NULL,
       G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
+  g_object_class_install_property (object_class, PROP_SERVICE,
+    g_param_spec_string ("service",
+      "Service",
+      "The service of this account, or NULL",
+      NULL,
+      G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+
   g_object_class_install_property (object_class, PROP_DISPLAY_NAME,
     g_param_spec_string ("display-name",
       "display-name",
@@ -298,13 +287,6 @@ empathy_account_settings_class_init (
       "Whether this account is ready to be used",
       FALSE,
       G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
-
-  signals[PASSWORD_RETRIEVED] =
-      g_signal_new ("password-retrieved",
-          G_TYPE_FROM_CLASS (empathy_account_settings_class),
-          G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-          g_cclosure_marshal_VOID__VOID,
-          G_TYPE_NONE, 0);
 }
 
 static void
@@ -322,11 +304,21 @@ empathy_account_settings_dispose (GObject *object)
     g_signal_handler_disconnect (priv->managers, priv->managers_ready_id);
   priv->managers_ready_id = 0;
 
-  tp_clear_object (&priv->managers);
-  tp_clear_object (&priv->manager);
-  tp_clear_object (&priv->account_manager);
-  tp_clear_object (&priv->account);
-  tp_clear_object (&priv->protocol_obj);
+  if (priv->managers != NULL)
+    g_object_unref (priv->managers);
+  priv->managers = NULL;
+
+  if (priv->manager != NULL)
+    g_object_unref (priv->manager);
+  priv->manager = NULL;
+
+  if (priv->account_manager != NULL)
+    g_object_unref (priv->account_manager);
+  priv->account_manager = NULL;
+
+  if (priv->account != NULL)
+    g_object_unref (priv->account);
+  priv->account = NULL;
 
   /* release any references held by the object here */
   if (G_OBJECT_CLASS (empathy_account_settings_parent_class)->dispose)
@@ -355,10 +347,9 @@ empathy_account_settings_finalize (GObject *object)
   /* free any data held directly by the object here */
   g_free (priv->cm_name);
   g_free (priv->protocol);
+  g_free (priv->service);
   g_free (priv->display_name);
   g_free (priv->icon_name);
-  g_free (priv->password);
-  g_free (priv->password_original);
 
   if (priv->required_params != NULL)
     g_array_free (priv->required_params, TRUE);
@@ -371,130 +362,11 @@ empathy_account_settings_finalize (GObject *object)
   G_OBJECT_CLASS (empathy_account_settings_parent_class)->finalize (object);
 }
 
-static void
-empathy_account_settings_protocol_obj_prepared_cb (GObject *source,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  EmpathyAccountSettings *self = user_data;
-  GError *error = NULL;
-
-  if (!tp_proxy_prepare_finish (source, result, &error))
-    {
-      DEBUG ("Failed to prepare protocol object: %s", error->message);
-      g_clear_error (&error);
-      return;
-    }
-
-  empathy_account_settings_check_readyness (self);
-}
-
-static void
-empathy_account_settings_get_password_cb (GObject *source,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  EmpathyAccountSettings *self = user_data;
-  EmpathyAccountSettingsPriv *priv = GET_PRIV (self);
-  const gchar *password;
-  GError *error = NULL;
-
-  password = empathy_keyring_get_password_finish (TP_ACCOUNT (source),
-      result, &error);
-
-  if (error != NULL)
-    {
-      DEBUG ("Failed to get password: %s", error->message);
-      g_clear_error (&error);
-    }
-
-  /* It doesn't really matter if getting the password failed; that
-   * just means that it's not there, or let's act like that at
-   * least. */
-
-  g_assert (priv->password == NULL);
-
-  priv->password = g_strdup (password);
-  priv->password_original = g_strdup (password);
-
-  g_signal_emit (self, signals[PASSWORD_RETRIEVED], 0);
-}
-
-static void
-empathy_account_settings_migrate_password_cb (GObject *source,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  TpAccount *account = TP_ACCOUNT (source);
-  GError *error = NULL;
-  EmpathyAccountSettings *self = user_data;
-  EmpathyAccountSettingsPriv *priv = GET_PRIV (self);
-  GHashTable *empty;
-  const gchar *unset[] = { "password", NULL };
-
-  if (!empathy_keyring_set_password_finish (account, result, &error))
-    {
-      DEBUG ("Failed to set password: %s", error->message);
-      g_clear_error (&error);
-      return;
-    }
-
-  /* Now clear the password MC has stored. */
-  empty = tp_asv_new (NULL, NULL);
-  tp_account_update_parameters_async (priv->account,
-      empty, unset, NULL, NULL);
-
-  g_hash_table_remove (priv->parameters, "password");
-
-  g_hash_table_unref (empty);
-}
-
-static void
-empathy_account_settings_try_migrating_password (EmpathyAccountSettings *self)
-{
-  EmpathyAccountSettingsPriv *priv = GET_PRIV (self);
-  const GValue *v;
-  const gchar *password;
-
-  if (!priv->supports_sasl || empathy_account_settings_get (
-          self, "password") == NULL)
-    return;
-
-  /* mission-control still has our password, although the CM
-   * supports SASL. Let's try migrating it. */
-
-  DEBUG ("Trying to migrate password parameter from MC to the "
-      "keyring ourselves for account %s",
-      tp_account_get_path_suffix (priv->account));
-
-  v = empathy_account_settings_get (self, "password");
-
-  /* I can't imagine why this would fail. */
-  if (!G_VALUE_HOLDS_STRING (v))
-    return;
-
-  password = g_value_get_string (v);
-
-  if (EMP_STR_EMPTY (password))
-    return;
-
-  empathy_keyring_set_password_async (priv->account, password,
-      empathy_account_settings_migrate_password_cb, self);
-
-  /* We don't want to request the password again, we
-   * already know it. */
-  priv->password_requested = TRUE;
-
-  priv->password = g_strdup (password);
-  priv->password_original = g_strdup (password);
-}
-
 static void
 empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (self);
   const TpConnectionManagerProtocol *tp_protocol;
-  GQuark features[] = { TP_PROTOCOL_FEATURE_CORE, 0 };
 
   if (priv->ready)
     return;
@@ -506,17 +378,12 @@ empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
   if (!empathy_connection_managers_is_ready (priv->managers))
     return;
 
-  if (priv->manager == NULL)
-    {
-      priv->manager = empathy_connection_managers_get_cm (
-          priv->managers, priv->cm_name);
-    }
+  priv->manager = empathy_connection_managers_get_cm (
+    priv->managers, priv->cm_name);
 
   if (priv->manager == NULL)
     return;
 
-  g_object_ref (priv->manager);
-
   if (priv->account != NULL)
     {
       g_free (priv->display_name);
@@ -533,7 +400,7 @@ empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
 
   if (tp_protocol == NULL)
     {
-      tp_clear_object (&priv->manager);
+      priv->manager = NULL;
       return;
     }
 
@@ -554,47 +421,7 @@ empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
         }
     }
 
-  if (priv->protocol_obj == NULL)
-    {
-      priv->protocol_obj = g_object_ref (
-          tp_connection_manager_get_protocol_object (priv->manager,
-              priv->protocol));
-    }
-
-  if (!tp_proxy_is_prepared (priv->protocol_obj, TP_PROTOCOL_FEATURE_CORE)
-      && !priv->preparing_protocol)
-    {
-      priv->preparing_protocol = TRUE;
-      tp_proxy_prepare_async (priv->protocol_obj, features,
-          empathy_account_settings_protocol_obj_prepared_cb, self);
-      return;
-    }
-  else
-    {
-      if (tp_strv_contains (tp_protocol_get_authentication_types (
-                  priv->protocol_obj),
-              TP_IFACE_CHANNEL_INTERFACE_SASL_AUTHENTICATION))
-        {
-          priv->supports_sasl = TRUE;
-        }
-    }
-
-  /* NOTE: When removing MC migration code, remove this call, and the
-   * function it's calling. That's it. */
-  empathy_account_settings_try_migrating_password (self);
-
-  /* priv->account won't be a proper account if it's the account
-   * assistant showing this widget. */
-  if (priv->supports_sasl && !priv->password_requested
-      && priv->account != NULL)
-    {
-      priv->password_requested = TRUE;
-
-      /* Make this call but don't block on its readiness. We'll signal
-       * if it's updated later with ::password-retrieved. */
-      empathy_keyring_get_password_async (priv->account,
-          empathy_account_settings_get_password_cb, self);
-    }
+  g_object_ref (priv->manager);
 
   priv->ready = TRUE;
   g_object_notify (G_OBJECT (self), "ready");
@@ -632,11 +459,13 @@ empathy_account_settings_managers_ready_cb (GObject *object,
 EmpathyAccountSettings *
 empathy_account_settings_new (const gchar *connection_manager,
     const gchar *protocol,
+    const gchar *service,
     const char *display_name)
 {
   return g_object_new (EMPATHY_TYPE_ACCOUNT_SETTINGS,
       "connection-manager", connection_manager,
       "protocol", protocol,
+      "service", service,
       "display-name", display_name,
       NULL);
 }
@@ -694,6 +523,14 @@ empathy_account_settings_get_protocol (EmpathyAccountSettings *settings)
   return priv->protocol;
 }
 
+const gchar *
+empathy_account_settings_get_service (EmpathyAccountSettings *settings)
+{
+  EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
+
+  return priv->service;
+}
+
 gchar *
 empathy_account_settings_get_icon_name (EmpathyAccountSettings *settings)
 {
@@ -756,13 +593,6 @@ empathy_account_settings_get_tp_param (EmpathyAccountSettings *settings,
   return NULL;
 }
 
-gboolean
-empathy_account_settings_have_tp_param (EmpathyAccountSettings *settings,
-    const gchar *param)
-{
-  return (empathy_account_settings_get_tp_param (settings, param) != NULL);
-}
-
 static void
 account_settings_remove_from_unset (EmpathyAccountSettings *settings,
     const gchar *param)
@@ -852,14 +682,6 @@ empathy_account_settings_unset (EmpathyAccountSettings *settings,
   if (empathy_account_settings_is_unset (settings, param))
     return;
 
-  if (priv->supports_sasl && !tp_strdiff (param, "password"))
-    {
-      g_free (priv->password);
-      priv->password = NULL;
-      priv->password_changed = TRUE;
-      return;
-    }
-
   v = g_strdup (param);
 
   g_array_append_val (priv->unset_parameters, v);
@@ -873,24 +695,14 @@ empathy_account_settings_discard_changes (EmpathyAccountSettings *settings)
 
   g_hash_table_remove_all (priv->parameters);
   empathy_account_settings_free_unset_parameters (settings);
-
-  priv->password_changed = FALSE;
-  g_free (priv->password);
-  priv->password = g_strdup (priv->password_original);
 }
 
 const gchar *
 empathy_account_settings_get_string (EmpathyAccountSettings *settings,
     const gchar *param)
 {
-  EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
   const GValue *v;
 
-  if (!tp_strdiff (param, "password") && priv->supports_sasl)
-    {
-      return priv->password;
-    }
-
   v = empathy_account_settings_get (settings, param);
 
   if (v == NULL || !G_VALUE_HOLDS_STRING (v))
@@ -1085,16 +897,7 @@ empathy_account_settings_set_string (EmpathyAccountSettings *settings,
   g_return_if_fail (param != NULL);
   g_return_if_fail (value != NULL);
 
-  if (!tp_strdiff (param, "password") && priv->supports_sasl)
-    {
-      g_free (priv->password);
-      priv->password = g_strdup (value);
-      priv->password_changed = TRUE;
-    }
-  else
-    {
-      tp_asv_set_string (priv->parameters, g_strdup (param), value);
-    }
+  tp_asv_set_string (priv->parameters, g_strdup (param), value);
 
   account_settings_remove_from_unset (settings, param);
 }
@@ -1106,6 +909,9 @@ empathy_account_settings_set_strv (EmpathyAccountSettings *settings,
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
 
+  g_return_if_fail (param != NULL);
+  g_return_if_fail (value != NULL);
+
   tp_asv_set_strv (priv->parameters, g_strdup (param), value);
 
   account_settings_remove_from_unset (settings, param);
@@ -1118,6 +924,8 @@ empathy_account_settings_set_int32 (EmpathyAccountSettings *settings,
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
 
+  g_return_if_fail (param != NULL);
+
   tp_asv_set_int32 (priv->parameters, g_strdup (param), value);
 
   account_settings_remove_from_unset (settings, param);
@@ -1130,6 +938,8 @@ empathy_account_settings_set_int64 (EmpathyAccountSettings *settings,
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
 
+  g_return_if_fail (param != NULL);
+
   tp_asv_set_int64 (priv->parameters, g_strdup (param), value);
 
   account_settings_remove_from_unset (settings, param);
@@ -1142,6 +952,8 @@ empathy_account_settings_set_uint32 (EmpathyAccountSettings *settings,
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
 
+  g_return_if_fail (param != NULL);
+
   tp_asv_set_uint32 (priv->parameters, g_strdup (param), value);
 
   account_settings_remove_from_unset (settings, param);
@@ -1154,6 +966,8 @@ empathy_account_settings_set_uint64 (EmpathyAccountSettings *settings,
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
 
+  g_return_if_fail (param != NULL);
+
   tp_asv_set_uint64 (priv->parameters, g_strdup (param), value);
 
   account_settings_remove_from_unset (settings, param);
@@ -1166,6 +980,8 @@ empathy_account_settings_set_boolean (EmpathyAccountSettings *settings,
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
 
+  g_return_if_fail (param != NULL);
+
   tp_asv_set_boolean (priv->parameters, g_strdup (param), value);
 
   account_settings_remove_from_unset (settings, param);
@@ -1202,6 +1018,8 @@ empathy_account_settings_set_display_name_async (
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
   GSimpleAsyncResult *result;
 
+  g_return_if_fail (name != NULL);
+
   result = g_simple_async_result_new (G_OBJECT (settings),
       callback, user_data, empathy_account_settings_set_display_name_finish);
 
@@ -1276,6 +1094,8 @@ empathy_account_settings_set_icon_name_async (
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
   GSimpleAsyncResult *result;
 
+  g_return_if_fail (name != NULL);
+
   result = g_simple_async_result_new (G_OBJECT (settings),
       callback, user_data, empathy_account_settings_set_icon_name_finish);
 
@@ -1312,55 +1132,6 @@ empathy_account_settings_set_icon_name_finish (
   return TRUE;
 }
 
-static void
-empathy_account_settings_processed_password (GObject *source,
-    GAsyncResult *result,
-    gpointer user_data,
-    gpointer finish_func)
-{
-  EmpathyAccountSettings *settings = EMPATHY_ACCOUNT_SETTINGS (user_data);
-  EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
-  GSimpleAsyncResult *r;
-  GError *error = NULL;
-  gboolean (*func) (TpAccount *source, GAsyncResult *result, GError **error) =
-    finish_func;
-
-  g_free (priv->password_original);
-  priv->password_original = g_strdup (priv->password);
-
-  if (!func (TP_ACCOUNT (source), result, &error))
-    {
-      g_simple_async_result_set_from_error (priv->apply_result, error);
-      g_error_free (error);
-    }
-
-  empathy_account_settings_discard_changes (settings);
-
-  r = priv->apply_result;
-  priv->apply_result = NULL;
-
-  g_simple_async_result_complete (r);
-  g_object_unref (r);
-}
-
-static void
-empathy_account_settings_set_password_cb (GObject *source,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  empathy_account_settings_processed_password (source, result, user_data,
-      empathy_keyring_set_password_finish);
-}
-
-static void
-empathy_account_settings_delete_password_cb (GObject *source,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  empathy_account_settings_processed_password (source, result, user_data,
-      empathy_keyring_delete_password_finish);
-}
-
 static void
 empathy_account_settings_account_updated (GObject *source,
     GAsyncResult *result,
@@ -1370,49 +1141,23 @@ empathy_account_settings_account_updated (GObject *source,
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
   GSimpleAsyncResult *r;
   GError *error = NULL;
-  GStrv reconnect_required = NULL;
 
   if (!tp_account_update_parameters_finish (TP_ACCOUNT (source),
-          result, &reconnect_required, &error))
+          result, NULL, &error))
     {
       g_simple_async_result_set_from_error (priv->apply_result, error);
       g_error_free (error);
-      goto out;
     }
-
-  /* Only set the password in the keyring if the CM supports SASL and
-   * it's changed. */
-  if (priv->supports_sasl && priv->password_changed)
+  else
     {
-      if (priv->password != NULL)
-        {
-          /* FIXME: we shouldn't save the password if we
-           * can't (MaySaveResponse=False) but we don't have API to check that
-           * at this point (fdo #35382). */
-          empathy_keyring_set_password_async (priv->account, priv->password,
-              empathy_account_settings_set_password_cb, settings);
-        }
-      else
-        {
-          empathy_keyring_delete_password_async (priv->account,
-              empathy_account_settings_delete_password_cb, settings);
-        }
-
-      return;
+      empathy_account_settings_discard_changes (settings);
     }
 
-  g_simple_async_result_set_op_res_gboolean (priv->apply_result,
-      g_strv_length (reconnect_required) > 0);
-
-out:
-  empathy_account_settings_discard_changes (settings);
-
   r = priv->apply_result;
   priv->apply_result = NULL;
 
   g_simple_async_result_complete (r);
   g_object_unref (r);
-  g_strfreev (reconnect_required);
 }
 
 static void
@@ -1436,19 +1181,6 @@ empathy_account_settings_created_cb (GObject *source,
   else
     {
       priv->account = g_object_ref (account);
-
-      if (priv->supports_sasl && priv->password != NULL)
-        {
-          /* Save the password before connecting */
-          /* FIXME: we shouldn't save the password if we
-           * can't (MaySaveResponse=False) but we don't have API to check that
-           * at this point (fdo #35382). */
-          empathy_keyring_set_password_async (priv->account,
-              priv->password, empathy_account_settings_set_password_cb,
-              settings);
-          return;
-        }
-
       empathy_account_settings_discard_changes (settings);
     }
 
@@ -1506,6 +1238,9 @@ empathy_account_settings_do_create_account (EmpathyAccountSettings *settings)
   tp_asv_set_string (properties, TP_IFACE_ACCOUNT ".Icon",
       priv->icon_name);
 
+  if (priv->service != NULL)
+    tp_asv_set_string (properties, TP_PROP_ACCOUNT_SERVICE, priv->service);
+
   tp_account_manager_create_account_async (priv->account_manager,
     priv->cm_name, priv->protocol, priv->display_name,
     priv->parameters, properties,
@@ -1554,10 +1289,6 @@ empathy_account_settings_apply_async (EmpathyAccountSettings *settings,
   priv->apply_result = g_simple_async_result_new (G_OBJECT (settings),
       callback, user_data, empathy_account_settings_apply_finish);
 
-  /* We'll have to reconnect only if we change none DBus_Property on an
-   * existing account. */
-  g_simple_async_result_set_op_res_gboolean (priv->apply_result, FALSE);
-
   if (priv->account == NULL)
     {
       tp_account_manager_prepare_async (priv->account_manager, NULL,
@@ -1574,7 +1305,6 @@ empathy_account_settings_apply_async (EmpathyAccountSettings *settings,
 gboolean
 empathy_account_settings_apply_finish (EmpathyAccountSettings *settings,
     GAsyncResult *result,
-    gboolean *reconnect_required,
     GError **error)
 {
   if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result),
@@ -1584,10 +1314,6 @@ empathy_account_settings_apply_finish (EmpathyAccountSettings *settings,
   g_return_val_if_fail (g_simple_async_result_is_valid (result,
     G_OBJECT (settings), empathy_account_settings_apply_finish), FALSE);
 
-  if (reconnect_required != NULL)
-    *reconnect_required = g_simple_async_result_get_op_res_gboolean (
-        G_SIMPLE_ASYNC_RESULT (result));
-
   return TRUE;
 }
 
@@ -1658,11 +1384,3 @@ empathy_account_settings_get_tp_protocol (EmpathyAccountSettings *self)
 
   return tp_connection_manager_get_protocol (priv->manager, priv->protocol);
 }
-
-gboolean
-empathy_account_settings_supports_sasl (EmpathyAccountSettings *self)
-{
-  EmpathyAccountSettingsPriv *priv = GET_PRIV (self);
-
-  return priv->supports_sasl;
-}
