@@ -539,7 +539,6 @@ empathy_protocol_name_to_display_name (const gchar *proto_name)
     gboolean translated;
   } names[] = {
     { "jabber", "Jabber", FALSE },
-    { "gtalk", "Google Talk", FALSE },
     { "msn", "MSN", FALSE, },
     { "local-xmpp", N_("People Nearby"), TRUE },
     { "irc", "IRC", FALSE },
@@ -547,7 +546,6 @@ empathy_protocol_name_to_display_name (const gchar *proto_name)
     { "aim", "AIM", FALSE },
     { "yahoo", "Yahoo!", FALSE },
     { "yahoojp", N_("Yahoo! Japan"), TRUE },
-    { "facebook", N_("Facebook Chat"), TRUE },
     { "groupwise", "GroupWise", FALSE },
     { "sip", "SIP", FALSE },
     { NULL, NULL }
@@ -558,13 +556,41 @@ empathy_protocol_name_to_display_name (const gchar *proto_name)
       if (!tp_strdiff (proto_name, names[i].proto))
         {
           if (names[i].translated)
-            return _(names[i].display);
+            return gettext (names[i].display);
           else
             return names[i].display;
         }
     }
 
-  return NULL;
+  return proto_name;
+}
+
+const char *
+empathy_service_name_to_display_name (const gchar *service_name)
+{
+  int i;
+  static struct {
+    const gchar *service;
+    const gchar *display;
+    gboolean translated;
+  } names[] = {
+    { "google-talk", N_("Google Talk"), FALSE },
+    { "facebook", N_("Facebook Chat"), TRUE },
+    { NULL, NULL }
+  };
+
+  for (i = 0; names[i].service != NULL; i++)
+    {
+      if (!tp_strdiff (service_name, names[i].service))
+        {
+          if (names[i].translated)
+            return gettext (names[i].display);
+          else
+            return names[i].display;
+        }
+    }
+
+  return service_name;
 }
 
 /* Note: this function depends on the account manager having its core feature
@@ -739,7 +765,7 @@ empathy_contact_dup_from_folks_individual (FolksIndividual *individual)
 
 TpChannelGroupChangeReason
 tp_channel_group_change_reason_from_folks_groups_change_reason (
-    FolksGroupableChangeReason reason)
+    FolksGroupsChangeReason reason)
 {
   return (TpChannelGroupChangeReason) reason;
 }
