@@ -319,7 +319,7 @@ account_assistant_apply_account_cb (GObject *source,
   EmpathyAccountSettings *settings = EMPATHY_ACCOUNT_SETTINGS (source);
   TpAccount *account;
 
-  empathy_account_settings_apply_finish (settings, result, NULL, &error);
+  empathy_account_settings_apply_finish (settings, result, &error);
 
   priv->is_creating = FALSE;
 
@@ -381,73 +381,19 @@ static void
 account_assistant_protocol_changed_cb (GtkComboBox *chooser,
     EmpathyAccountAssistant *self)
 {
-  TpConnectionManager *cm;
-  TpConnectionManagerProtocol *proto;
   EmpathyAccountSettings *settings;
   EmpathyAccountAssistantPriv *priv;
-  char *str;
   GtkWidget *account_widget;
   EmpathyAccountWidget *widget_object = NULL;
-  gboolean is_gtalk, is_facebook;
-  const gchar *name;
 
   priv = GET_PRIV (self);
 
-  cm = empathy_protocol_chooser_dup_selected (
-      EMPATHY_PROTOCOL_CHOOSER (chooser), &proto, &is_gtalk, &is_facebook);
+  settings = empathy_protocol_chooser_create_account_settings (
+      EMPATHY_PROTOCOL_CHOOSER (chooser));
 
-  if (cm == NULL || proto == NULL)
-    /* we are not ready yet */
+  if (settings == NULL)
     return;
 
-  /* Create account */
-  if (is_gtalk)
-    name = "gtalk";
-  else if (is_facebook)
-    name = "facebook";
-  else
-    name = proto->name;
-
-  /* To translator: %s is the protocol name */
-  str = g_strdup_printf (_("New %s account"),
-      empathy_protocol_name_to_display_name (name));
-
-  settings = empathy_account_settings_new (cm->name, proto->name, str);
-
-  if (is_gtalk)
-    {
-      gchar *fallback_servers[] = {
-          "talkx.l.google.com",
-          "talkx.l.google.com:443,oldssl",
-          "talkx.l.google.com:80",
-          NULL};
-
-      gchar *extra_certificate_identities[] = {
-          "talk.google.com",
-          NULL};
-
-      empathy_account_settings_set_icon_name_async (settings, "im-google-talk",
-        NULL, NULL);
-
-      empathy_account_settings_set_strv (settings, "fallback-servers",
-          fallback_servers);
-
-      if (empathy_account_settings_have_tp_param (settings,
-              "extra-certificate-identities"))
-        {
-          empathy_account_settings_set_strv (settings,
-                  "extra-certificate-identities", extra_certificate_identities);
-        }
-    }
-  else if (is_facebook)
-    {
-      empathy_account_settings_set_icon_name_async (settings, "im-facebook",
-        NULL, NULL);
-
-      empathy_account_settings_set_string (settings, "server",
-          "chat.facebook.com");
-    }
-
   if (priv->first_resp == RESPONSE_CREATE_ACCOUNT)
     empathy_account_settings_set_boolean (settings, "register", TRUE);
 
@@ -481,16 +427,13 @@ account_assistant_protocol_changed_cb (GtkComboBox *chooser,
   gtk_box_pack_start (GTK_BOX (priv->enter_or_create_page), account_widget,
       FALSE, FALSE, 0);
   gtk_widget_show (account_widget);
-
-  g_free (str);
 }
 
 static gboolean
 account_assistant_chooser_enter_details_filter_func (
     TpConnectionManager *cm,
     TpConnectionManagerProtocol *protocol,
-    gboolean is_gtalk,
-    gboolean is_facebook,
+    const gchar *service,
     gpointer user_data)
 {
   if (!tp_strdiff (protocol->name, "local-xmpp"))
@@ -503,11 +446,10 @@ static gboolean
 account_assistant_chooser_create_account_filter_func (
     TpConnectionManager *cm,
     TpConnectionManagerProtocol *protocol,
-    gboolean is_gtalk,
-    gboolean is_facebook,
+    const gchar *service,
     gpointer user_data)
 {
-  if (is_gtalk || is_facebook)
+  if (service != NULL)
     return FALSE;
 
   return tp_connection_manager_protocol_can_register (protocol);
@@ -829,12 +771,9 @@ account_assistant_build_enter_or_create_page (EmpathyAccountAssistant *self)
   gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 12);
   gtk_widget_show (main_vbox);
 
-  hbox = gtk_hbox_new (FALSE, 6);
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, FALSE, 0);
-  gtk_widget_show (hbox);
-
   w = gtk_label_new (NULL);
-  gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
+  gtk_misc_set_alignment (GTK_MISC (w), 0, 0);
+  gtk_box_pack_start (GTK_BOX (main_vbox), w, FALSE, FALSE, 0);
   gtk_widget_show (w);
   priv->first_label = w;
 
@@ -844,7 +783,7 @@ account_assistant_build_enter_or_create_page (EmpathyAccountAssistant *self)
   gtk_widget_show (w);
 
   chooser = empathy_protocol_chooser_new ();
-  gtk_box_pack_start (GTK_BOX (hbox), chooser, FALSE, FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (w), chooser);
   gtk_widget_show (chooser);
   priv->chooser = chooser;
 
@@ -1161,8 +1100,8 @@ account_assistant_build_salut_page (EmpathyAccountAssistant *self)
 
   g_object_unref (pix);
 
-  w = gtk_check_button_new_with_mnemonic (
-      _("I do _not want to enable this feature for now"));
+  w = gtk_check_button_new_with_label (
+      _("I don't want to enable this feature for now"));
   gtk_box_pack_start (GTK_BOX (main_vbox), w, FALSE, FALSE, 0);
   g_signal_connect (w, "toggled",
       G_CALLBACK (create_salut_check_box_toggled_cb), self);
