@@ -51,8 +51,6 @@
 #include <libempathy-gtk/empathy-contact-list-store.h>
 #include <libempathy-gtk/empathy-contact-list-view.h>
 #include <libempathy-gtk/empathy-live-search.h>
-#include <libempathy-gtk/empathy-contact-blocking-dialog.h>
-#include <libempathy-gtk/empathy-contact-search-dialog.h>
 #include <libempathy-gtk/empathy-geometry.h>
 #include <libempathy-gtk/empathy-gtk-enum-types.h>
 #include <libempathy-gtk/empathy-individual-dialogs.h>
@@ -66,7 +64,6 @@
 #include <libempathy-gtk/empathy-ui-utils.h>
 
 #include "empathy-accounts-dialog.h"
-#include "empathy-call-observer.h"
 #include "empathy-chat-manager.h"
 #include "empathy-main-window.h"
 #include "empathy-preferences.h"
@@ -109,7 +106,6 @@ struct _EmpathyMainWindowPriv {
 	TpAccountManager        *account_manager;
 	EmpathyChatroomManager  *chatroom_manager;
 	EmpathyEventManager     *event_manager;
-	EmpathyCallObserver     *call_observer;
 	guint                    flash_timeout_id;
 	gboolean                 flash_on;
 	gboolean                 empty;
@@ -124,7 +120,6 @@ struct _EmpathyMainWindowPriv {
 	GtkWidget              *presence_toolbar;
 	GtkWidget              *presence_chooser;
 	GtkWidget              *errors_vbox;
-	GtkWidget              *auth_vbox;
 	GtkWidget              *search_bar;
 	GtkWidget              *notebook;
 	GtkWidget              *no_entry_label;
@@ -145,13 +140,8 @@ struct _EmpathyMainWindowPriv {
 	GtkWidget              *edit_context_separator;
 
 	guint                   size_timeout_id;
-
-	/* reffed TpAccount* => visible GtkInfoBar* */
 	GHashTable             *errors;
 
-	/* EmpathyEvent* => visible GtkInfoBar* */
-	GHashTable             *auths;
-
 	/* stores a mapping from TpAccount to Handler ID to prevent
 	 * to listen more than once to the status-changed signal */
 	GHashTable             *status_changed_handlers;
@@ -293,138 +283,6 @@ main_window_flash_start (EmpathyMainWindow *window)
 	main_window_flash_cb (window);
 }
 
-static void
-main_window_remove_auth (EmpathyMainWindow *window,
-			 EmpathyEvent      *event)
-{
-	EmpathyMainWindowPriv *priv = GET_PRIV (window);
-	GtkWidget *error_widget;
-
-	error_widget = g_hash_table_lookup (priv->auths, event);
-	if (error_widget != NULL) {
-		gtk_widget_destroy (error_widget);
-		g_hash_table_remove (priv->auths, event);
-	}
-}
-
-static void
-main_window_auth_add_clicked_cb (GtkButton         *button,
-				 EmpathyMainWindow *window)
-{
-	EmpathyEvent *event;
-
-	event = g_object_get_data (G_OBJECT (button), "event");
-
-	empathy_event_approve (event);
-
-	main_window_remove_auth (window, event);
-}
-
-static void
-main_window_auth_close_clicked_cb (GtkButton         *button,
-				   EmpathyMainWindow *window)
-{
-	EmpathyEvent *event;
-
-	event = g_object_get_data (G_OBJECT (button), "event");
-
-	empathy_event_decline (event);
-	main_window_remove_auth (window, event);
-}
-
-static void
-main_window_auth_display (EmpathyMainWindow *window,
-			  EmpathyEvent      *event)
-{
-	EmpathyMainWindowPriv *priv = GET_PRIV (window);
-	TpAccount *account = event->account;
-	GtkWidget *info_bar;
-	GtkWidget *content_area;
-	GtkWidget *image;
-	GtkWidget *label;
-	GtkWidget *add_button;
-	GtkWidget *close_button;
-	GtkWidget *action_area;
-	GtkWidget *action_table;
-	const gchar *icon_name;
-	gchar *str;
-
-	if (g_hash_table_lookup (priv->auths, event) != NULL) {
-		return;
-	}
-
-	info_bar = gtk_info_bar_new ();
-	gtk_info_bar_set_message_type (GTK_INFO_BAR (info_bar), GTK_MESSAGE_QUESTION);
-
-	gtk_widget_set_no_show_all (info_bar, TRUE);
-	gtk_box_pack_start (GTK_BOX (priv->auth_vbox), info_bar, FALSE, TRUE, 0);
-	gtk_widget_show (info_bar);
-
-	icon_name = tp_account_get_icon_name (account);
-	image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_SMALL_TOOLBAR);
-	gtk_widget_show (image);
-
-	str = g_markup_printf_escaped ("<b>%s</b>\n%s",
-				       tp_account_get_display_name (account),
-				       _("Password required"));
-
-	label = gtk_label_new (str);
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-
-	g_free (str);
-
-	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (info_bar));
-	gtk_box_pack_start (GTK_BOX (content_area), image, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (content_area), label, TRUE, TRUE, 0);
-
-	image = gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON);
-	add_button = gtk_button_new ();
-	gtk_button_set_image (GTK_BUTTON (add_button), image);
-	gtk_widget_set_tooltip_text (add_button, _("Provide Password"));
-	gtk_widget_show (add_button);
-
-	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_BUTTON);
-	close_button = gtk_button_new ();
-	gtk_button_set_image (GTK_BUTTON (close_button), image);
-	gtk_widget_set_tooltip_text (close_button, _("Disconnect"));
-	gtk_widget_show (close_button);
-
-	action_table = gtk_table_new (1, 2, FALSE);
-	gtk_table_set_col_spacings (GTK_TABLE (action_table), 6);
-	gtk_widget_show (action_table);
-
-	action_area = gtk_info_bar_get_action_area (GTK_INFO_BAR (info_bar));
-	gtk_box_pack_start (GTK_BOX (action_area), action_table, FALSE, FALSE, 0);
-
-	gtk_table_attach (GTK_TABLE (action_table), add_button, 0, 1, 0, 1,
-			  (GtkAttachOptions) (GTK_SHRINK),
-			  (GtkAttachOptions) (GTK_SHRINK), 0, 0);
-	gtk_table_attach (GTK_TABLE (action_table), close_button, 1, 2, 0, 1,
-			  (GtkAttachOptions) (GTK_SHRINK),
-			  (GtkAttachOptions) (GTK_SHRINK), 0, 0);
-
-	g_object_set_data_full (G_OBJECT (info_bar),
-				"event", event, NULL);
-	g_object_set_data_full (G_OBJECT (add_button),
-				"event", event, NULL);
-	g_object_set_data_full (G_OBJECT (close_button),
-				"event", event, NULL);
-
-	g_signal_connect (add_button, "clicked",
-			  G_CALLBACK (main_window_auth_add_clicked_cb),
-			  window);
-	g_signal_connect (close_button, "clicked",
-			  G_CALLBACK (main_window_auth_close_clicked_cb),
-			  window);
-
-	gtk_widget_show (priv->auth_vbox);
-
-	g_hash_table_insert (priv->auths, event, info_bar);
-}
-
 static void
 main_window_event_added_cb (EmpathyEventManager *manager,
 			    EmpathyEvent        *event,
@@ -432,8 +290,6 @@ main_window_event_added_cb (EmpathyEventManager *manager,
 {
 	if (event->contact) {
 		main_window_flash_start (window);
-	} else if (event->type == EMPATHY_EVENT_TYPE_AUTH) {
-		main_window_auth_display (window, event);
 	}
 }
 
@@ -445,11 +301,6 @@ main_window_event_removed_cb (EmpathyEventManager *manager,
 	EmpathyMainWindowPriv *priv = GET_PRIV (window);
 	FlashForeachData data;
 
-	if (event->type == EMPATHY_EVENT_TYPE_AUTH) {
-		main_window_remove_auth (window, event);
-		return;
-	}
-
 	if (!event->contact) {
 		return;
 	}
@@ -534,9 +385,6 @@ main_window_row_deleted_cb (GtkTreeModel      *model,
 			gtk_label_set_markup (GTK_LABEL (priv->no_entry_label), tmp);
 			g_free (tmp);
 
-			gtk_label_set_ellipsize (GTK_LABEL (priv->no_entry_label),
-				PANGO_ELLIPSIZE_END);
-
 			gtk_notebook_set_current_page (
 					GTK_NOTEBOOK (priv->notebook), PAGE_NO_MATCH);
 		}
@@ -618,134 +466,6 @@ main_window_error_close_clicked_cb (GtkButton         *button,
 	main_window_remove_error (window, account);
 }
 
-static void
-main_window_error_upgrade_sw_clicked_cb (GtkButton         *button,
-					 EmpathyMainWindow *window)
-{
-	TpAccount *account;
-	GtkWidget *dialog;
-
-	account = g_object_get_data (G_OBJECT (button), "account");
-	main_window_remove_error (window, account);
-
-	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-		GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
-		GTK_BUTTONS_OK,
-		_("Sorry, %s accounts can’t be used until your %s software is updated."),
-		tp_account_get_protocol (account),
-		tp_account_get_protocol (account));
-
-	g_signal_connect_swapped (dialog, "response",
-		G_CALLBACK (gtk_widget_destroy),
-		dialog);
-
-	gtk_widget_show (dialog);
-}
-
-static void
-main_window_upgrade_software_error (EmpathyMainWindow *window,
-				    TpAccount         *account)
-{
-	EmpathyMainWindowPriv *priv = GET_PRIV (window);
-	GtkWidget *info_bar;
-	GtkWidget *content_area;
-	GtkWidget *label;
-	GtkWidget *image;
-	GtkWidget *upgrade_button;
-	GtkWidget *close_button;
-	GtkWidget *action_area;
-	GtkWidget *action_table;
-	gchar     *str;
-	const gchar     *icon_name;
-	const gchar *error_message;
-	gboolean user_requested;
-
-	error_message =
-		empathy_account_get_error_message (account, &user_requested);
-
-	if (user_requested) {
-		return;
-	}
-
-	str = g_markup_printf_escaped ("<b>%s</b>\n%s",
-					       tp_account_get_display_name (account),
-					       error_message);
-
-	/* If there are other errors, remove them */
-	main_window_remove_error (window, account);
-
-	info_bar = gtk_info_bar_new ();
-	gtk_info_bar_set_message_type (GTK_INFO_BAR (info_bar), GTK_MESSAGE_ERROR);
-
-	gtk_widget_set_no_show_all (info_bar, TRUE);
-	gtk_box_pack_start (GTK_BOX (priv->errors_vbox), info_bar, FALSE, TRUE, 0);
-	gtk_widget_show (info_bar);
-
-	icon_name = tp_account_get_icon_name (account);
-	image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_SMALL_TOOLBAR);
-	gtk_widget_show (image);
-
-	label = gtk_label_new (str);
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-	g_free (str);
-
-	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (info_bar));
-	gtk_box_pack_start (GTK_BOX (content_area), image, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (content_area), label, TRUE, TRUE, 0);
-
-	image = gtk_image_new_from_stock (GTK_STOCK_REFRESH, GTK_ICON_SIZE_BUTTON);
-	upgrade_button = gtk_button_new ();
-	gtk_button_set_image (GTK_BUTTON (upgrade_button), image);
-	gtk_widget_set_tooltip_text (upgrade_button, _("Update software..."));
-	gtk_widget_show (upgrade_button);
-
-	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_BUTTON);
-	close_button = gtk_button_new ();
-	gtk_button_set_image (GTK_BUTTON (close_button), image);
-	gtk_widget_set_tooltip_text (close_button, _("Close"));
-	gtk_widget_show (close_button);
-
-	action_table = gtk_table_new (1, 2, FALSE);
-	gtk_table_set_col_spacings (GTK_TABLE (action_table), 2);
-	gtk_widget_show (action_table);
-
-	action_area = gtk_info_bar_get_action_area (GTK_INFO_BAR (info_bar));
-	gtk_box_pack_start (GTK_BOX (action_area), action_table, FALSE, FALSE, 0);
-
-	gtk_table_attach (GTK_TABLE (action_table), upgrade_button, 0, 1, 0, 1,
-										(GtkAttachOptions) (GTK_SHRINK),
-										(GtkAttachOptions) (GTK_SHRINK), 0, 0);
-	gtk_table_attach (GTK_TABLE (action_table), close_button, 1, 2, 0, 1,
-										(GtkAttachOptions) (GTK_SHRINK),
-										(GtkAttachOptions) (GTK_SHRINK), 0, 0);
-
-	g_object_set_data (G_OBJECT (info_bar), "label", label);
-	g_object_set_data_full (G_OBJECT (info_bar),
-				"account", g_object_ref (account),
-				g_object_unref);
-	g_object_set_data_full (G_OBJECT (upgrade_button),
-				"account", g_object_ref (account),
-				g_object_unref);
-	g_object_set_data_full (G_OBJECT (close_button),
-				"account", g_object_ref (account),
-				g_object_unref);
-
-	g_signal_connect (upgrade_button, "clicked",
-			  G_CALLBACK (main_window_error_upgrade_sw_clicked_cb),
-			  window);
-	g_signal_connect (close_button, "clicked",
-			  G_CALLBACK (main_window_error_close_clicked_cb),
-			  window);
-
-	gtk_widget_set_tooltip_text (priv->errors_vbox, error_message);
-	gtk_widget_show (priv->errors_vbox);
-
-	g_hash_table_insert (priv->errors, g_object_ref (account), info_bar);
-}
-
 static void
 main_window_error_display (EmpathyMainWindow *window,
 			   TpAccount         *account)
@@ -765,12 +485,6 @@ main_window_error_display (EmpathyMainWindow *window,
 	const gchar *error_message;
 	gboolean user_requested;
 
-	if (!tp_strdiff (TP_ERROR_STR_SOFTWARE_UPGRADE_REQUIRED,
-			 tp_account_get_detailed_error (account, NULL))) {
-		main_window_upgrade_software_error (window, account);
-		return;
-	}
-
 	error_message =
 		empathy_account_get_error_message (account, &user_requested);
 
@@ -874,7 +588,6 @@ main_window_error_display (EmpathyMainWindow *window,
 			  G_CALLBACK (main_window_error_retry_clicked_cb),
 			  window);
 
-	gtk_widget_set_tooltip_text (priv->errors_vbox, error_message);
 	gtk_widget_show (priv->errors_vbox);
 
 	g_hash_table_insert (priv->errors, g_object_ref (account), info_bar);
@@ -980,7 +693,6 @@ empathy_main_window_finalize (GObject *window)
 	g_object_unref (priv->account_manager);
 	g_object_unref (priv->individual_store);
 	g_hash_table_destroy (priv->errors);
-	g_hash_table_destroy (priv->auths);
 
 	/* disconnect all handlers of status-changed signal */
 	g_hash_table_iter_init (&iter, priv->status_changed_handlers);
@@ -996,7 +708,6 @@ empathy_main_window_finalize (GObject *window)
 	g_signal_handlers_disconnect_by_func (priv->event_manager,
 			  		      main_window_event_removed_cb,
 			  		      window);
-	g_object_unref (priv->call_observer);
 	g_object_unref (priv->event_manager);
 	g_object_unref (priv->ui_manager);
 	g_object_unref (priv->chatroom_manager);
@@ -1014,7 +725,7 @@ main_window_key_press_event_cb  (GtkWidget   *window,
 {
 	EmpathyChatManager *chat_manager;
 
-	if (event->keyval == GDK_T
+	if (event->keyval == GDK_KEY_T
 	    && event->state & GDK_SHIFT_MASK
 	    && event->state & GDK_CONTROL_MASK) {
 		chat_manager = empathy_chat_manager_dup_singleton ();
@@ -1059,15 +770,6 @@ main_window_chat_add_contact_cb (GtkAction         *action,
 	empathy_new_individual_dialog_show (GTK_WINDOW (window));
 }
 
-static void
-main_window_chat_search_contacts_cb (GtkAction         *action,
-				     EmpathyMainWindow *window)
-{
-	GtkWidget *dialog = empathy_contact_search_dialog_new (
-			GTK_WINDOW (window));
-	gtk_widget_show (dialog);
-}
-
 static void
 main_window_view_show_ft_manager (GtkAction         *action,
 				  EmpathyMainWindow *window)
@@ -1573,18 +1275,6 @@ main_window_edit_personal_information_cb (GtkAction         *action,
 	empathy_contact_personal_dialog_show (GTK_WINDOW (window));
 }
 
-static void
-main_window_edit_blocked_contacts_cb (GtkAction         *action,
-		                      EmpathyMainWindow *window)
-{
-	GtkWidget *dialog;
-
-	dialog = empathy_contact_blocking_dialog_new (GTK_WINDOW (window));
-	gtk_widget_show (dialog);
-	g_signal_connect (dialog, "response",
-			G_CALLBACK (gtk_widget_destroy), NULL);
-}
-
 static void
 main_window_edit_preferences_cb (GtkAction         *action,
 				 EmpathyMainWindow *window)
@@ -1736,8 +1426,7 @@ main_window_connection_items_setup (EmpathyMainWindow *window,
 		"chat_new_message",
 		"chat_new_call",
 		"chat_add_contact",
-		"edit_personal_information",
-		"edit_blocked_contacts"
+		"edit_personal_information"
 	};
 
 	for (i = 0, list = NULL; i < G_N_ELEMENTS (actions_connected); i++) {
@@ -1871,7 +1560,6 @@ empathy_main_window_init (EmpathyMainWindow *window)
 	gui = empathy_builder_get_file (filename,
 				       "main_vbox", &priv->main_vbox,
 				       "errors_vbox", &priv->errors_vbox,
-				       "auth_vbox", &priv->auth_vbox,
 				       "ui_manager", &priv->ui_manager,
 				       "view_show_offline", &show_offline_widget,
 				       "view_show_protocols", &priv->show_protocols,
@@ -1905,7 +1593,6 @@ empathy_main_window_init (EmpathyMainWindow *window)
 			      "room_join_favorites", "activate", main_window_room_join_favorites_cb,
 			      "room_manage_favorites", "activate", main_window_room_manage_favorites_cb,
 			      "chat_add_contact", "activate", main_window_chat_add_contact_cb,
-			      "chat_search_contacts", "activate", main_window_chat_search_contacts_cb,
 			      "view_show_ft_manager", "activate", main_window_view_show_ft_manager,
 			      "view_show_offline", "toggled", main_window_view_show_offline_cb,
 			      "view_show_protocols", "toggled", main_window_view_show_protocols_cb,
@@ -1915,7 +1602,6 @@ empathy_main_window_init (EmpathyMainWindow *window)
 			      "edit", "activate", main_window_edit_cb,
 			      "edit_accounts", "activate", main_window_edit_accounts_cb,
 			      "edit_personal_information", "activate", main_window_edit_personal_information_cb,
-			      "edit_blocked_contacts", "activate", main_window_edit_blocked_contacts_cb,
 			      "edit_preferences", "activate", main_window_edit_preferences_cb,
 			      "help_about", "activate", main_window_help_about_cb,
 			      "help_debug", "activate", main_window_help_debug_cb,
@@ -1942,8 +1628,6 @@ empathy_main_window_init (EmpathyMainWindow *window)
 					      g_object_unref,
 					      NULL);
 
-	priv->auths = g_hash_table_new (NULL, NULL);
-
 	priv->status_changed_handlers = g_hash_table_new_full (g_direct_hash,
 							       g_direct_equal,
 							       NULL,
@@ -1968,7 +1652,6 @@ empathy_main_window_init (EmpathyMainWindow *window)
 	gtk_widget_show (priv->presence_chooser);
 	item = gtk_tool_item_new ();
 	gtk_widget_show (GTK_WIDGET (item));
-	gtk_widget_set_size_request (priv->presence_chooser, 10, -1);
 	gtk_container_add (GTK_CONTAINER (item), priv->presence_chooser);
 	gtk_tool_item_set_is_important (item, TRUE);
 	gtk_tool_item_set_expand (item, TRUE);
@@ -1978,7 +1661,6 @@ empathy_main_window_init (EmpathyMainWindow *window)
 	priv->throbber = gtk_spinner_new ();
 	gtk_widget_set_size_request (priv->throbber, 16, -1);
 	gtk_widget_set_tooltip_text (priv->throbber, _("Show and edit accounts"));
-	gtk_widget_set_has_window (GTK_WIDGET (priv->throbber), TRUE);
 	gtk_widget_set_events (priv->throbber, GDK_BUTTON_PRESS_MASK);
 	g_signal_connect (priv->throbber, "button-press-event",
 		G_CALLBACK (main_window_throbber_button_press_event_cb),
@@ -2045,7 +1727,6 @@ empathy_main_window_init (EmpathyMainWindow *window)
 	empathy_geometry_bind (GTK_WINDOW (window), GEOMETRY_NAME);
 
 	/* Enable event handling */
-	priv->call_observer = empathy_call_observer_dup_singleton ();
 	priv->event_manager = empathy_event_manager_dup_singleton ();
 
 	g_signal_connect (priv->event_manager, "event-added",
